@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Ryu::Node);
 
-our $VERSION = '2.007'; # VERSION
+our $VERSION = '2.008'; # VERSION
 our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 =head1 NAME
@@ -1093,6 +1093,33 @@ sub merge : method {
     $combined
 }
 
+=head2 emit_from
+
+Emits items as they are generated by the given sources.
+
+Example:
+
+ my $src = Ryu::Source->new;
+ $src->say;
+ $src->emit_from(
+  $numbers,
+  $letters
+ );
+
+=cut
+
+sub emit_from : method {
+    my ($self, @sources) = @_;
+
+    for my $src (@sources) {
+        $src->each_while_source(sub {
+            return if $self->completed->is_ready;
+            $self->emit($_)
+        }, $self);
+    }
+    $self
+}
+
 =head2 apply
 
 Used for setting up multiple streams.
